@@ -377,6 +377,9 @@ class KernelCupy(object):
             if hasattr(arg.atype, "_dtype"):  # it is numerical scalar
                 return arg.atype(value)  # try to return a numpy scalar
             elif hasattr(arg.atype, "_size"):  # it is a compound xobject
+                assert value._buffer.context is self.context, (
+                    f"Incompatible context for argument `{arg.name}`"
+                )
                 return value._buffer.buffer[value._offset :]
             else:
                 raise ValueError(
